@@ -13,3 +13,10 @@ from ssh_proxy_server.forwarders.ssh import (
     SSHForwarder,
     SSHLogForwarder
 )
+
+from ssh_proxy_server.forwarders.sftp import (
+    SFTPBaseHandle,
+    SFTPHandlerBasePlugin,
+    SFTPHandlerPlugin,
+    SFTPHandlerStoragePlugin
+)
